Capability enum

Capability markers inferred from presentation-layer folder structure.

Inheritance
Available extensions

Values

presentationControllers → const Capability

Presence of controller-style presentation state.

presentationProviders → const Capability

Presence of provider-style presentation state.

presentationBlocs → const Capability

Presence of bloc/cubit presentation state.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
label String

Available on Capability, provided by the CapabilityLabel extension

Canonical serialized label used in compatibility messages.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Capability>
A constant List of the values in this enum, in order of their declaration.