DeprecationsConfig class

Policy for deprecated-key handling behavior.

Constructors

DeprecationsConfig({required String policy})
Creates deprecations policy config.

Properties

hashCode int
The hash code for this object.
no setterinherited
policy String
Policy value (warn or error).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited