FeaturesConfig class

Feature-level scaffold configuration.

Constructors

FeaturesConfig({required String basePath, required Map<String, List<String>> structure})
Creates features config.

Properties

basePath String
Base path for all generated features.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structure Map<String, List<String>>
Section-to-folder structure map for each feature.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited