ProjectConfig class

Project-level scaffold configuration.

Constructors

ProjectConfig({required List<String> core})
Creates project config.

Properties

core List<String>
Core folder names to scaffold under lib/core.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited