ProjectGenerationResult class

Result summary for project structure generation.

Constructors

ProjectGenerationResult({required List<String> createdPaths, required List<String> skippedPaths})
Creates a project generation result.

Properties

createdPaths List<String>
Paths created during generation.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skippedPaths List<String>
Paths skipped because they already existed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited