ProjectGenerator class

Generates project-level scaffold directories.

Constructors

ProjectGenerator({FileUtils? fileUtils})
Creates a project generator.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate({required Directory projectRoot, required ArchSherpaConfig config, bool dryRun = false}) ProjectGenerationResult
Creates configured core and features base directories.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited