FileUtilsException class

Exception thrown when a filesystem operation violates safety constraints.

Implemented types

Constructors

FileUtilsException(String message)
Creates a file utility exception with a human-readable message.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Error description suitable for CLI diagnostics.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited