ConfigLoadResult class
Effective configuration with source metadata and deprecation warnings.
Constructors
-
ConfigLoadResult({required ArchSherpaConfig config, required ConfigSource source, required List<
String> warnings}) - Creates a configuration load result.
Properties
- config → ArchSherpaConfig
-
Resolved effective configuration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → ConfigSource
-
Primary source used during resolution.
final
-
warnings
→ List<
String> -
Deprecation warnings found while loading raw config.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited